from setuptools import setup, find_packages
setup(
  name = 'Pinch',
  packages = find_packages(),
  version = '0.1.5',
  description = 'A simple gem to easily connect to the Inch Housing Intervention Interface',
  author = 'Inch',
  author_email = 'thomas@inchbase.com',
  url = 'https://github.com/Uelb/pinch-python', # use the URL to the github repo
  download_url = 'https://github.com/Uelb/pinch-python/tarball/v0.1.0', # I'll explain this in a second
  keywords = ['company', 'api', 'housing', 'intervention', 'geronimo', 'inch'], # arbitrary keywords
  classifiers = [],
)
